==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/user/messages/hr/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => '<strong>Postavke</strong> računa',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Potvrdite</strong> vašu novu email adresu',
    '<strong>User</strong> modules' => '<strong>Korisnički</strong> moduli',
    '<strong>User</strong> settings' => '<strong>Korisničke</strong> postavke',
    '<strong>Your</strong> profile' => '<strong>Vaš</strong> profil',
    'All your personal data will be irrevocably deleted.' => 'Svi vaši osobni podaci bit će neopozivo izbrisani.',
    'Are you really sure? *ALL* module data for your profile will be deleted!' => 'Jeste li sigurni? Izbrisat će se podaci o modulima * ALL * za vaš profil!',
    'Are you sure that you want to delete your account?' => 'Jeste li sigurni da želite izbrisati svoj račun?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Promjenom korisničkog imena neke veze mogu postati neupotrebljive, na primjer stare veze do profila.',
    'Configure' => 'Konfiguriraj',
    'Confirm' => 'Potvrdi',
    'Current password' => 'Trenutačna lozinka',
    'Delete account' => 'Obriši račun',
    'Disable' => 'Onemogući',
    'Do you really want to delete your icon image?' => 'Želite li zaista izbrisati sliku svoje ikone?',
    'Do you really want to delete your logo image?' => 'Želite li izbrisati vaš logo?',
    'E-Mail' => 'E-Mail',
    'E-Mail change' => 'Promijeni E-mail',
    'Enable' => 'Omogući',
    'Enhance your profile with modules.' => 'Poboljšajte svoj profil pomoću modula.',
    'Enter your password to continue' => 'Unesite lozinku za nastavak',
    'Hello' => 'Pozdrav',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Ovdje možete urediti opće podatke profila, što je vidljivo na stranici o vašem profilu.',
    'Hide introduction tour panel on dashboard' => 'Sakrij uvodni panel na upravljačkoj ploči',
    'Invalid link! Please make sure that you entered the entire url.' => 'Nevažeća poveznica! Provjerite jeste li unijeli cijeli URL.',
    'Language' => 'Jezik',
    'Modules' => 'Moduli',
    'New E-Mail address' => 'Nova E-mail adresa',
    'New User name' => 'Novo korisničko ime',
    'Not registered users' => 'Ne registrirani korisnici',
    'Notifications' => 'Obavijesti',
    'Other users' => 'Ostali korisnici',
    'Password Recovery' => 'Oporavak lozinke',
    'Permissions' => 'Dozvole',
    'Profile' => 'Profil',
    'Profile visibility' => 'Vidljivost profila',
    'Registered users only' => 'Samo registrirani korisnici',
    'Save' => 'Spremi',
    'Save profile' => 'Spremi profil',
    'Settings' => 'Postavke',
    'Tags' => 'Tagovi',
    'The entered e-mail address is already in use by another user.' => 'Unesena e-mail adresa već je u upotrebi.',
    'TimeZone' => 'Vremenska zona',
    'Username has been changed' => 'Korisničko ime je promijenjeno',
    'Users' => 'Korisnici',
    'Visible for all (also unregistered users)' => 'Vidljivo za sve (i neregistrirane korisnike)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Upravo smo poslali potvrdu e-pošte na vašu novu adresu. <br> Slijedite upute u mailu.',
    'You are currently the owner of following spaces:' => 'Trenutno ste vlasnik sljedećih prostora:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Zatražili ste promjenu adrese e-pošte.<br>Vaša nova e-adresa je {newemail}.<br><br>Za potvrdu nove adrese e-pošte molimo kliknite na donji gumb.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Uspješno ste promijenili korisničko ime.<br>Novo korisničko ime je {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Morate prenijeti vlasništvo ili izbrisati ove prostore prije nego što možete izbrisati svoj račun.',
    'Your account cannot be deleted!' => 'Vaš račun se ne može izbrisati!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Vaša trenutačna adresa e-pošte je <b>{email} b&gt;.Ovdje možete promijeniti trenutnu adresu e-pošte.</b>',
    'Your current password can be changed here.' => 'Vašu lozinku možete ovdje promijeniti.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Vaše je trenutno korisničko ime <b>{username}</b>.Ovdje možete promijeniti svoje trenutno korisničko ime.',
    'Your e-mail address has been successfully changed to {email}.' => 'Vaša e-adresa uspješno je promijenjena u {email}.',
    'Your friends' => 'Vaši prijatelji',
    'Your password has been successfully changed!' => 'Vaša lozinka je uspiješno promijenjena!',
    'Your username has been changed' => 'Vaše korisničko ime je promijenjeno',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Vaše korisničko ime uspješno je promijenjeno.<br>Upravo smo vam poslali e-mail s novim informacijama.',
    '{attribute} "{value}" was not found!' => '{attribute} "{value}" nije pronađen!',
    '<strong>Permissions</strong>' => '',
    'Blocked users' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/hr/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Potvrdite</strong> vašu novu email adresu',
    '<strong>Your</strong> profile' => '<strong>Vaš</strong> profil',
    'All your personal data will be irrevocably deleted.' => 'Svi vaši osobni podaci bit će neopozivo izbrisani.',
    'Are you sure that you want to delete your account?' => 'Jeste li sigurni da želite izbrisati svoj račun?',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Promjenom korisničkog imena neke veze mogu postati neupotrebljive, na primjer stare veze do profila.',
    'Confirm' => 'Potvrdi',
    'Current password' => 'Trenutačna lozinka',
    'Delete account' => 'Obriši račun',
    'Do you really want to delete your icon image?' => 'Želite li zaista izbrisati sliku svoje ikone?',
    'Do you really want to delete your logo image?' => 'Želite li izbrisati vaš logo?',
    'E-Mail' => 'E-Mail',
    'E-Mail change' => 'Promijeni E-mail',
    'Enter your password to continue' => 'Unesite lozinku za nastavak',
    'Hello' => 'Pozdrav',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Ovdje možete urediti opće podatke profila, što je vidljivo na stranici o vašem profilu.',
    'Hide introduction tour panel on dashboard' => 'Sakrij uvodni panel na upravljačkoj ploči',
    'Invalid link! Please make sure that you entered the entire url.' => 'Nevažeća poveznica! Provjerite jeste li unijeli cijeli URL.',
    'Language' => 'Jezik',
    'Modules' => 'Moduli',
    'New E-Mail address' => 'Nova E-mail adresa',
    'New User name' => 'Novo korisničko ime',
    'Not registered users' => 'Ne registrirani korisnici',
    'Notifications' => 'Obavijesti',
    'Other users' => 'Ostali korisnici',
    'Password Recovery' => 'Oporavak lozinke',
    'Permissions' => 'Dozvole',
    'Profile' => 'Profil',
    'Profile visibility' => 'Vidljivost profila',
    'Registered users only' => 'Samo registrirani korisnici',
    'Save' => 'Spremi',
    'Save profile' => 'Spremi profil',
    'The entered e-mail address is already in use by another user.' => 'Unesena e-mail adresa već je u upotrebi.',
    'TimeZone' => 'Vremenska zona',
    'Username has been changed' => 'Korisničko ime je promijenjeno',
    'Users' => 'Korisnici',
    'Visible for all (also unregistered users)' => 'Vidljivo za sve (i neregistrirane korisnike)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Upravo smo poslali potvrdu e-pošte na vašu novu adresu. <br> Slijedite upute u mailu.',
    'You are currently the owner of following spaces:' => 'Trenutno ste vlasnik sljedećih prostora:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Zatražili ste promjenu adrese e-pošte.<br>Vaša nova e-adresa je {newemail}.<br><br>Za potvrdu nove adrese e-pošte molimo kliknite na donji gumb.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Uspješno ste promijenili korisničko ime.<br>Novo korisničko ime je {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Morate prenijeti vlasništvo ili izbrisati ove prostore prije nego što možete izbrisati svoj račun.',
    'Your account cannot be deleted!' => 'Vaš račun se ne može izbrisati!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Vaša trenutačna adresa e-pošte je <b>{email} b&gt;.Ovdje možete promijeniti trenutnu adresu e-pošte.</b>',
    'Your current password can be changed here.' => 'Vašu lozinku možete ovdje promijeniti.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Vaše je trenutno korisničko ime <b>{username}</b>.Ovdje možete promijeniti svoje trenutno korisničko ime.',
    'Your e-mail address has been successfully changed to {email}.' => 'Vaša e-adresa uspješno je promijenjena u {email}.',
    'Your friends' => 'Vaši prijatelji',
    'Your password has been successfully changed!' => 'Vaša lozinka je uspiješno promijenjena!',
    'Your username has been changed' => 'Vaše korisničko ime je promijenjeno',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Vaše korisničko ime uspješno je promijenjeno.<br>Upravo smo vam poslali e-mail s novim informacijama.',
    '{attribute} "{value}" was not found!' => '{attribute} "{value}" nije pronađen!',
    '<strong>Account</strong> Settings' => '',
    '<strong>Permissions</strong>' => '',
    '<strong>User</strong> Account' => '',
    'Account Settings' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'Blocked users' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Profile Tags' => '',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => '',
    'You cannot use this username.' => '',
];
